<div align="center">
<h1>🍲 HuoguoML</h1>
</div>


HuoguoML is a platform for managing and serving machine learning models. It provides a set of functionalities that can be used with all existing machine learning applications. Key features are:

- HuoguoML Tracking: An API to log parameters, code, and results of machine learning experiments 
- HuoguoML Dashboard: A powerful dashboard for comparing and analysing logged experiments
- HuoguoML Service: A CLI to easily launch a REST service from your logged experiments that can be updated over the air


## Installation

Get the latest stable version of HuoguoML:

```bash
pip install huoguoml
```

or get the development version, which is updated with every commit on the main branch:

```bash
pip install huoguoml-dev
```


## Examples

Just starting out? Try out our examples:

| Example                          | Description   | 
| --------------------------       | -------------| 
| [MNIST](examples/mnist)    | Deployment of a MNIST classifier with HuoguoML and Tensorflow | 

## Documentation

Apart from learning from the examples, we highly recommended you go through our [documentation](https://steven-mi.gitbook.io/huoguoml/).

Our docs are built on every push to the main or dev branch.

## Contributors

We encourage you to contribute to HuoguoML! Please check out the [Contributing guide](CONTRIBUTING.md) for guidelines about how to proceed.


## License

Apache License Version 2.0, see [LICENSE](LICENSE)